"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GenerateReportUseCase = void 0;
const tslib_1 = require("tslib");
const tsyringe_1 = require("tsyringe");
const git_report_implementation_repository_1 = require("../../infrastructure/git-report.implementation.repository");
const git_report_list_1 = require("../../domain/git-report-list");
const git_report_printer_1 = require("../../infrastructure/cli/git-report.printer");
let GenerateReportUseCase = class GenerateReportUseCase {
    constructor(repository, printer) {
        this.repository = repository;
        this.printer = printer;
    }
    async exec({ projectsPaths, weeks }) {
        const progress = this.printer.generateProgressBar('git projects loaded');
        progress.start(projectsPaths.length, 0);
        if (projectsPaths.length === 0) {
            progress.stop();
            return new git_report_list_1.GitReportList([]).mergeReports();
        }
        const { successfulReports, failedReports } = await this.generateReports(projectsPaths, weeks, progress);
        progress.stop();
        this.printer.printFailedReports(failedReports);
        return new git_report_list_1.GitReportList(successfulReports).mergeReports();
    }
    async generateReports(projectsPaths, weeks, progress) {
        const reports = await Promise.all(projectsPaths.map(async (projectPath) => {
            // Sucks awaiting something inside a Promise.all,
            // but otherwise the progress bar will be waiting once completed.
            // This is because when you run a Promise.all all the callbacks will be executed
            // and after that the event loop will be waiting for all the promises to be fulfilled.
            const report = await this.repository.readGitReport(projectPath, weeks);
            progress.increment();
            return report;
        }));
        return {
            successfulReports: reports.filter(report => !report.hasFailed()),
            failedReports: reports.filter(report => report.hasFailed()),
        };
    }
};
GenerateReportUseCase = tslib_1.__decorate([
    tsyringe_1.injectable(),
    tslib_1.__param(0, tsyringe_1.inject(git_report_implementation_repository_1.GitReportImplementationRepository)),
    tslib_1.__param(1, tsyringe_1.inject(git_report_printer_1.GitReportPrinter)),
    tslib_1.__metadata("design:paramtypes", [Object, git_report_printer_1.GitReportPrinter])
], GenerateReportUseCase);
exports.GenerateReportUseCase = GenerateReportUseCase;
//# sourceMappingURL=generate-report.case.js.map