"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GitReportList = void 0;
const git_report_1 = require("./git-report");
/**
 * Inmutable list of git reports
 */
class GitReportList {
    constructor(values) {
        this.values = values;
    }
    mergeReports() {
        return this.values.reduce((acc, report) => new git_report_1.GitReport({
            weeks: report.weeks,
            projects: [...acc.projects, ...report.projects],
            committers: GitReportList.combineCommitters(acc.committers, report.committers),
        }), GitReportList.emptyGitReport);
    }
    static combineCommitters(accCommitters, committers) {
        return Object.values([...accCommitters, ...committers].reduce((committersDictionary, committer) => {
            const accumulatedCommitterInfo = GitReportList.getCommitter(committer.email, committersDictionary);
            return {
                ...committersDictionary,
                [committer.email]: {
                    email: committer.email,
                    name: committer.name,
                    totalDeletions: committer.totalDeletions + accumulatedCommitterInfo.totalDeletions,
                    totalInsertions: committer.totalInsertions + accumulatedCommitterInfo.totalInsertions,
                    totalCommits: committer.totalCommits + accumulatedCommitterInfo.totalCommits,
                    totalFilesChanged: committer.totalFilesChanged + accumulatedCommitterInfo.totalFilesChanged,
                },
            };
        }, {}));
    }
    static getCommitter(committerEmail, committersDictionary) {
        const committer = committersDictionary[committerEmail];
        return committer || {
            email: committerEmail,
            name: '',
            totalDeletions: 0,
            totalInsertions: 0,
            totalCommits: 0,
            totalFilesChanged: 0,
        };
    }
}
exports.GitReportList = GitReportList;
GitReportList.emptyGitReport = new git_report_1.GitReport({
    committers: [],
    projects: [],
    weeks: 0,
});
//# sourceMappingURL=git-report-list.js.map