"use strict";
var GitReportPrinter_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.GitReportPrinter = void 0;
const tslib_1 = require("tslib");
const tsyringe_1 = require("tsyringe");
const cli_ux_1 = require("cli-ux");
const logger_1 = require("../../../core/infrastructure/logger");
const colorette_1 = require("colorette");
const path_1 = tslib_1.__importDefault(require("path"));
const os_1 = require("os");
const version_1 = tslib_1.__importDefault(require("../../../version"));
let GitReportPrinter = GitReportPrinter_1 = class GitReportPrinter {
    constructor(logger) {
        this.logger = logger;
    }
    info(...text) {
        this.logger.info(...text);
    }
    error(...text) {
        this.logger.error(...text);
    }
    generateProgressBar(conceptToProgressAbout) {
        return cli_ux_1.cli.progress({
            format: `PROGRESS | ${colorette_1.green('{bar}')} | ${colorette_1.green('{value}/{total}')} ${conceptToProgressAbout}.`,
            barCompleteChar: '\u2588',
            barIncompleteChar: '\u2591',
            hideCursor: true,
        });
    }
    printInit() {
        this.logger.info(colorette_1.underline(`Initializing git reporter ${version_1.default}${os_1.EOL}`));
    }
    printStartFetchingDirectory(pathToDirectory) {
        this.logger.info(`🔍 Starting to fetch git logs for projects in directory ${path_1.default.resolve(pathToDirectory)}.${os_1.EOL}`);
    }
    printStartFetchingProjects(projectsPath) {
        const projectsAbsolutePaths = projectsPath.map(project => path_1.default.resolve(project));
        this.logger.info(`🔍 Starting to fetch git logs for: ${os_1.EOL}  - ${projectsAbsolutePaths.map(GitReportPrinter_1.extractProjectName).join(`${os_1.EOL}  - `)}${os_1.EOL}`);
    }
    printFailedReports(failedReports) {
        if (failedReports.length > 0) {
            this.logger.error(`${os_1.EOL}🚨 The following projects failed to get git log:`);
            for (const { projects } of failedReports) {
                this.logger.error(`  - ${projects.map(colorette_1.red).join(`${os_1.EOL}  - `)}`);
            }
        }
    }
    static extractProjectName(absoluteProjectPath) {
        return absoluteProjectPath.slice(absoluteProjectPath.lastIndexOf('/') + 1);
    }
};
GitReportPrinter = GitReportPrinter_1 = tslib_1.__decorate([
    tsyringe_1.singleton(),
    tslib_1.__param(0, tsyringe_1.inject(logger_1.Logger)),
    tslib_1.__metadata("design:paramtypes", [logger_1.Logger])
], GitReportPrinter);
exports.GitReportPrinter = GitReportPrinter;
//# sourceMappingURL=git-report.printer.js.map