"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GitReportController = void 0;
const tslib_1 = require("tslib");
const tsyringe_1 = require("tsyringe");
const path_1 = tslib_1.__importDefault(require("path"));
const generate_anonymize_report_for_projects_in_directory_case_1 = require("../application/cases/generate-anonymize-report-for-projects-in-directory.case");
const generate_anonymize_report_case_1 = require("../application/cases/generate-anonymize-report.case");
const generate_report_case_1 = require("../application/cases/generate-report.case");
const generate_report_for_projects_in_directory_case_1 = require("../application/cases/generate-report-for-projects-in-directory.case");
const notifier_1 = require("../../core/infrastructure/notifier");
const git_report_printer_1 = require("./cli/git-report.printer");
let GitReportController = class GitReportController {
    constructor(notifier, printer) {
        this.notifier = notifier;
        this.printer = printer;
    }
    async exec({ directory, anonymize, projects, weeks, slackUrl, }) {
        const report = directory ?
            await this.executeReportForDirectory(directory, anonymize, weeks) :
            await this.executeReportForMultipleProjects(projects, anonymize, weeks);
        await this.printAndNotifyReport(report, slackUrl);
    }
    async executeReportForDirectory(allInDirectory, anonymize, weeks) {
        this.printer.printStartFetchingDirectory(allInDirectory);
        return anonymize ?
            tsyringe_1.container.resolve(generate_anonymize_report_for_projects_in_directory_case_1.GenerateAnonymizeReportForProjectsInDirectoryUseCase).exec({
                directoryPath: allInDirectory,
                weeks,
            }) :
            tsyringe_1.container.resolve(generate_report_for_projects_in_directory_case_1.GenerateReportForProjectsInDirectoryUseCase).exec({
                directoryPath: allInDirectory,
                weeks,
            });
    }
    async executeReportForMultipleProjects(projects, anonymize, weeks) {
        this.printer.printStartFetchingProjects(projects);
        const projectsAbsolutePaths = projects.map(project => path_1.default.resolve(project));
        return anonymize ?
            tsyringe_1.container.resolve(generate_anonymize_report_case_1.GenerateAnonymizeReportUseCase).exec({
                projectsPaths: projectsAbsolutePaths,
                weeks,
            }) :
            tsyringe_1.container.resolve(generate_report_case_1.GenerateReportUseCase).exec({
                projectsPaths: projectsAbsolutePaths,
                weeks,
            });
    }
    async printAndNotifyReport(report, slackUrl) {
        this.printer.info(report.toString());
        await this.notifyReport(slackUrl, report.toString());
    }
    async notifyReport(slackUrl, reportOutput) {
        if (slackUrl) {
            await this.notifier.publishOnSlack(slackUrl, reportOutput);
            this.printer.info('Report published on Slack.');
        }
    }
};
GitReportController = tslib_1.__decorate([
    tsyringe_1.injectable(),
    tslib_1.__param(0, tsyringe_1.inject(notifier_1.Notifier)),
    tslib_1.__param(1, tsyringe_1.inject(git_report_printer_1.GitReportPrinter)),
    tslib_1.__metadata("design:paramtypes", [notifier_1.Notifier,
        git_report_printer_1.GitReportPrinter])
], GitReportController);
exports.GitReportController = GitReportController;
//# sourceMappingURL=git-report.controller.js.map