"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GitReportImplementationRepository = void 0;
const tslib_1 = require("tslib");
const tsyringe_1 = require("tsyringe");
const path_1 = tslib_1.__importDefault(require("path"));
const shell_1 = require("../../core/infrastructure/shell");
const git_report_mapper_1 = require("./git-report.mapper");
const os_1 = require("os");
let GitReportImplementationRepository = class GitReportImplementationRepository {
    constructor(shell) {
        this.shell = shell;
    }
    async readGitReport(projectPath, weeks) {
        try {
            const absolutePath = path_1.default.resolve(projectPath);
            await this.shell.run(`git -C ${absolutePath} fetch && git -C ${absolutePath} pull`);
            const gitLog = await this.shell.run(`git -C ${absolutePath} log --after="${weeks} weeks ago" --all --pretty=format:'%an | %ae' --shortstat`);
            return git_report_mapper_1.GitReportMapper.toDomain(gitLog, weeks, projectPath);
        }
        catch (error) {
            return git_report_mapper_1.GitReportMapper.toDomain(undefined, weeks, projectPath);
        }
    }
    async readGitProjects(directoryPath) {
        const absolutePath = path_1.default.resolve(directoryPath);
        const list = await this.shell.run(`ls -dl ${absolutePath}/*/.git`);
        if (list.includes('no matches found')) {
            return [];
        }
        return list.split(os_1.EOL).map(line => line.split(' ').slice(-1)[0].replace('/.git', '')).filter(Boolean);
    }
};
GitReportImplementationRepository = tslib_1.__decorate([
    tsyringe_1.injectable(),
    tslib_1.__param(0, tsyringe_1.inject(shell_1.Shell)),
    tslib_1.__metadata("design:paramtypes", [shell_1.Shell])
], GitReportImplementationRepository);
exports.GitReportImplementationRepository = GitReportImplementationRepository;
//# sourceMappingURL=git-report.implementation.repository.js.map